@@ -8,6 +8,7 @@ use openssl::hash::{hash, DigestBytes, MessageDigest};
 use openssl::rsa::{Padding, Rsa};
 use openssl::symm::{encrypt, Cipher};
 use rand::rngs::OsRng;
+use rand::Rng;
 use rand::RngCore;
 use urlqstring::QueryParams;
 use AesMode::{cbc, ecb};
@@ -43,6 +44,20 @@ impl Crypto {
         hex::encode(data)
     }
 
+    pub fn alpha_lowercase_random_bytes(n: usize) -> String {
+        const CHARSET: &[u8] = b"abcdefghijklmnopqrstuvwxyz0123456789";
+        let mut rng = rand::thread_rng();
+
+        let rand_string: String = (0..n)
+            .map(|_| {
+                let idx = rng.gen_range(0..CHARSET.len());
+                CHARSET[idx] as char
+            })
+            .collect();
+
+        rand_string
+    }
+
     pub fn eapi(url: &str, text: &str) -> String {
         let message = format!("nobody{}use{}md5forencrypt", url, text);
         let digest = hex::encode(hash(MessageDigest::md5(), message.as_bytes()).unwrap());
